@@ -1,6 +1,7 @@
 """Kernel connection helpers."""
 import json
 import struct
+from typing import Any, List
 
 from jupyter_client.session import Session
 from tornado.websocket import WebSocketHandler
@@ -87,14 +88,14 @@ def serialize_msg_to_ws_v1(msg_or_list, channel, pack=None):
     else:
         msg_list = msg_or_list
     channel = channel.encode("utf-8")
-    offsets: list = []
+    offsets: List[Any] = []
     offsets.append(8 * (1 + 1 + len(msg_list) + 1))
     offsets.append(len(channel) + offsets[-1])
     for msg in msg_list:
         offsets.append(len(msg) + offsets[-1])
     offset_number = len(offsets).to_bytes(8, byteorder="little")
     offsets = [offset.to_bytes(8, byteorder="little") for offset in offsets]
-    bin_msg = b"".join([offset_number, *offsets] + [channel] + msg_list)
+    bin_msg = b"".join([offset_number, *offsets, channel, *msg_list])
     return bin_msg
 
 
@@ -171,7 +172,7 @@ class BaseKernelWebsocketConnection(LoggingConfigurable):
         """Handle an incoming message."""
         raise NotImplementedError()
 
-    def handle_outgoing_message(self, stream: str, outgoing_msg: list) -> None:
+    def handle_outgoing_message(self, stream: str, outgoing_msg: List[Any]) -> None:
         """Handle an outgoing message."""
         raise NotImplementedError()
 
